#include "dll.ch"
#include "common.ch"

//--error codes from MAPI.H
#define SUCCESS_SUCCESS                     0
#define MAPI_USER_ABORT                     1
#define MAPI_E_FAILURE                      2
#define MAPI_E_LOGIN_FAILURE                3
#define MAPI_E_DISK_FULL                    4
#define MAPI_E_INSUFFICIENT_MEMORY          5
#define MAPI_E_ACCESS_DENIED                6
#define MAPI_E_TOO_MANY_SESSIONS            8
#define MAPI_E_TOO_MANY_FILES               9
#define MAPI_E_TOO_MANY_RECIPIENTS          10
#define MAPI_E_ATTACHMENT_NOT_FOUND         11
#define MAPI_E_ATTACHMENT_OPEN_FAILURE      12
#define MAPI_E_ATTACHMENT_WRITE_FAILURE     13
#define MAPI_E_UNKNOWN_RECIPIENT            14
#define MAPI_E_BAD_RECIPTYPE                15
#define MAPI_E_NO_MESSAGES                  16
#define MAPI_E_INVALID_MESSAGE              17
#define MAPI_E_TEXT_TOO_LARGE               18
#define MAPI_E_INVALID_SESSION              19
#define MAPI_E_TYPE_NOT_SUPPORTED           20
#define MAPI_E_AMBIGUOUS_RECIPIENT          21
#define MAPI_E_MESSAGE_IN_USE               22
#define MAPI_E_NETWORK_FAILURE              23
#define MAPI_E_INVALID_EDITFIELDS           24
#define MAPI_E_INVALID_RECIPS               25
#define MAPI_E_NOT_SUPPORTED                26

//--IDs for Message items
#define ID_SUBJECT                0
#define ID_MESSAGE                1
#define ID_MESSAGE_TYPE           2
#define ID_DATE                   3
#define ID_ORIGINATOR_NAME        4
#define ID_ORIGINATOR_ADRESS      5
#define ID_RECIPIENT_NAME         6
#define ID_RECIPIENT_ADRESS       7
#define ID_ATTACHMENT_PATHNAME    8
#define ID_ATTACHMENT_FILENAME    9
#define ID_CONVERSATION_ID        10

//--Message Flags
#define NOFLAG                    0
#define FLAG_UNREAD               1
#define FLAG_RECEIPT_REQUESTED    2
#define FLAG_SENT                 4

//--SKIP Flags
#define SKIP_ONLY                 0
#define DELETE_THEN_SKIP          1



//*************************************************************************** SendSOCMapiMail
/*
 cAdresses    := "Jim@xxx.com;"     +;
                 "John@yyy.com;"    +;
                 "CC:Jane@zzz.com;" +;
                 "BCC:Tom@www.com"
 cSubject     := "Hello World"
 cMessage     := "This is the Test message"
 cAttachments := "C:\autoexec.bat;C:\config.sys"
*/




function SendSOCMapiMail(cAdresses,cSubject,cMessage,cAttachments)

local nFlag        :=  NOFLAG
local nErr, ret_val := .f.
local snDllHandle
local diskSave := diskname()
local dirsave := dirname()

    default cAdresses to "", cSubject to "", cMessage to "", cAttachments to ""


do while .t.
      //Load DLL
      if ( snDllHandle := DllLoad( "SocMapi.Dll" ) )  == 0
        MsgBox("Fehler: Funktion nicht mglich - SOCMAPI.DLL nicht vorhanden!")
        exit
      endif
      if ( nErr := DllCall( snDllHandle, DLL_STDCALL, "SocMapiInit" ) )  !=  SUCCESS_SUCCESS
        NotifyError( nErr )
        exit
      endif
      // Logon when new MAPI session
      if  DllCall( snDllHandle, DLL_STDCALL,"SocMapiIsLoggedOn"  ) == 0
        if (nErr := DllCall(snDllHandle, DLL_STDCALL, "SocMapiLogon")) != SUCCESS_SUCCESS
            NotifyError( nErr )
            exit
        endif
      endif

      // Oem to Ansi
      cAdresses:= ConvToAnsiCP( cAdresses )
      cSubject := ConvToAnsiCP( cSubject )
      cMessage := ConvToAnsiCP( cMessage )

      //-- Pop up maileditor
      nErr := DllCall( snDllHandle, DLL_STDCALL, "SocMapiSendMail" , cAdresses , cSubject, cMessage, cAttachments, nFlag )
      if nErr != SUCCESS_SUCCESS
         NotifyError( nErr )
         exit
      endif

      ret_val := .t.

      DllCall( snDllHandle, DLL_STDCALL, "SocMapiLogoff" )
      DllunLoad( snDllHandle )
      exit
  enddo

  diskchange( DiskSave )  // Restore Disk/Path  David can change it ...
  dirchange( DirSave )

return(ret_val)
//***************************************************************************  SendSOCMapiMail


//*************************************************************************** NotifyError
static PROCEDURE NotifyError( nErr )
local cErr
    do case
        case nErr==SUCCESS_SUCCESS                ; cErr := "Erfolgreich!"
        case nErr==MAPI_USER_ABORT                ; cErr := "Benutzer Abbruch        "
        case nErr==MAPI_E_FAILURE                 ; cErr := "Fehlgeschlagen          "
        case nErr==MAPI_E_LOGIN_FAILURE           ; cErr := "Anmeldefefehler-Kein Zugriff auf Mailprogramm"
        case nErr==MAPI_E_DISK_FULL               ; cErr := "DISK_FULL               "
        case nErr==MAPI_E_INSUFFICIENT_MEMORY     ; cErr := "INSUFFICIENT_MEMORY     "
        case nErr==MAPI_E_ACCESS_DENIED           ; cErr := "Zugriff verweigert      "
        case nErr==MAPI_E_TOO_MANY_SESSIONS       ; cErr := "TOO_MANY_SESSIONS       "
        case nErr==MAPI_E_TOO_MANY_FILES          ; cErr := "TOO_MANY_FILES          "
        case nErr==MAPI_E_TOO_MANY_RECIPIENTS     ; cErr := "TOO_MANY_RECIPIENTS     "
        case nErr==MAPI_E_ATTACHMENT_NOT_FOUND    ; cErr := "ATTACHMENT_NOT_FOUND    "
        case nErr==MAPI_E_ATTACHMENT_OPEN_FAILURE ; cErr := "ATTACHMENT_OPEN_FAILURE "
        case nErr==MAPI_E_ATTACHMENT_WRITE_FAILURE; cErr := "ATTACHMENT_WRITE_FAILURE"
        case nErr==MAPI_E_UNKNOWN_RECIPIENT       ; cErr := "UNKNOWN_RECIPIENT       "
        case nErr==MAPI_E_BAD_RECIPTYPE           ; cErr := "BAD_RECIPTYPE           "
        case nErr==MAPI_E_NO_MESSAGES             ; cErr := "NO_MESSAGES             "
        case nErr==MAPI_E_INVALID_MESSAGE         ; cErr := "INVALID_MESSAGE         "
        case nErr==MAPI_E_TEXT_TOO_LARGE          ; cErr := "TEXT_TOO_LARGE          "
        case nErr==MAPI_E_INVALID_SESSION         ; cErr := "INVALID_SESSION         "
        case nErr==MAPI_E_TYPE_NOT_SUPPORTED      ; cErr := "TYPE_NOT_SUPPORTED      "
        case nErr==MAPI_E_AMBIGUOUS_RECIPIENT     ; cErr := "AMBIGUOUS_RECIPIENT     "
        case nErr==MAPI_E_MESSAGE_IN_USE          ; cErr := "MESSAGE_IN_USE          "
        case nErr==MAPI_E_NETWORK_FAILURE         ; cErr := "NETWORK_FAILURE         "
        case nErr==MAPI_E_INVALID_EDITFIELDS      ; cErr := "INVALID_EDITFIELDS      "
        case nErr==MAPI_E_INVALID_RECIPS          ; cErr := "INVALID_RECIPS          "
        case nErr==MAPI_E_NOT_SUPPORTED           ; cErr := "NOT_SUPPORTED (32/64Bit)"
        otherwise                                 ; cErr := "Unknown Mapi Error"

    endcase
    MsgBox("SOCMAPI Funktionsfehler: eMail senden nicht mglich!"+chr(13)+"Fehlercode: " + ALLTRIM(str(nErr)) + " - " + cErr ,"SOCMAPI32 Fehler" )

return
//*************************************************************************** NotifyError

